Test Select and Pause

Test AndWait commands for Reload
open | ../tests/html/test_reload_onchange_page.html |
clickAndWait | theLink |
verifyTitle | Slow Loading Page |
open | ../tests/html/test_reload_onchange_page.html |
selectAndWait | theSelect | Second Option
verifyTitle | Slow Loading Page |
open | ../tests/html/test_reload_onchange_page.html |
type | theTextbox | new value
fireEventAndWait | theTextbox | blur
verifyTitle | Slow Loading Page |
open | ../tests/html/test_reload_onchange_page.html |
clickAndWait | theSubmit |
verifyTitle | Slow Loading Page |
clickAndWait | slowPage_reload |
verifyTitle | Slow Loading Page |